"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLayers = exports.convertComponentTypesToLayersWithCache = exports.convertComponentTypesToLayers = void 0;
const react_1 = __importStar(require("react"));
const inputLayersToLayers = (layers) => {
    return layers.map((layer) => {
        if (layer.type === 'web') {
            return {
                component: react_1.default.lazy(() => Promise.resolve({ default: layer.component })),
                type: 'web',
            };
        }
        // No lazy for Video allowed!
        if (layer.type === 'video') {
            return {
                component: layer.component,
                type: 'video',
            };
        }
        // No lazy for SVG allowed!
        return {
            component: layer.component,
            type: 'svg',
        };
    });
};
const convertComponentTypesToLayers = (compProps) => {
    if ('component' in compProps) {
        // In SSR, suspense is not yet supported, we cannot use React.lazy
        if (typeof document === 'undefined') {
            return [
                {
                    component: compProps.component,
                    type: 'web',
                },
            ];
        }
        return [
            {
                component: react_1.default.lazy(() => Promise.resolve({ default: compProps.component })),
                type: 'web',
            },
        ];
    }
    if ('lazyComponent' in compProps) {
        return [
            {
                component: react_1.default.lazy(compProps.lazyComponent),
                type: 'web',
            },
        ];
    }
    if ('layers' in compProps) {
        return inputLayersToLayers(compProps.layers);
    }
    throw new Error('Unknown component type');
};
exports.convertComponentTypesToLayers = convertComponentTypesToLayers;
const convertComponentTypesToLayersWithCache = (compProps, prevCompProps, prevReturnValue) => {
    if ('component' in compProps) {
        if (prevCompProps &&
            'component' in prevCompProps &&
            compProps.component === prevCompProps.component &&
            prevReturnValue) {
            return prevReturnValue;
        }
        return [
            {
                type: 'web',
                component: react_1.default.lazy(() => Promise.resolve({ default: compProps.component })),
            },
        ];
    }
    if ('lazyComponent' in compProps) {
        if (prevCompProps &&
            'lazyComponent' in prevCompProps &&
            compProps.lazyComponent === prevCompProps.lazyComponent &&
            prevReturnValue) {
            return prevReturnValue;
        }
        return [
            {
                type: 'web',
                component: react_1.default.lazy(compProps.lazyComponent),
            },
        ];
    }
    if ('layers' in compProps) {
        const isTheSame = () => {
            if (!prevCompProps) {
                return false;
            }
            if (!('layers' in prevCompProps)) {
                return false;
            }
            if (compProps.layers.length !== prevCompProps.layers.length) {
                return false;
            }
            for (let i = 0; i < compProps.layers.length; i++) {
                if (compProps.layers[i].component !== prevCompProps.layers[i].component) {
                    return false;
                }
                if (compProps.layers[i].type !== prevCompProps.layers[i].type) {
                    return false;
                }
            }
            return true;
        };
        if (isTheSame()) {
            return prevReturnValue;
        }
        return inputLayersToLayers(compProps.layers);
    }
    throw new Error('Unknown component type');
};
exports.convertComponentTypesToLayersWithCache = convertComponentTypesToLayersWithCache;
const useLayers = (compProps) => {
    var _a, _b;
    const prevCompProps = (0, react_1.useRef)();
    const prevLayers = (0, react_1.useRef)();
    const layers = (0, exports.convertComponentTypesToLayersWithCache)(compProps, (_a = prevCompProps.current) !== null && _a !== void 0 ? _a : null, (_b = prevLayers.current) !== null && _b !== void 0 ? _b : null);
    prevCompProps.current = compProps;
    prevLayers.current = layers;
    return layers;
};
exports.useLayers = useLayers;
